==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateSMEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToClassSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstanceSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToClassSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToCreatorSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreateSMEventStatementSetImpl extends InstanceSet<CreateSMEventStatementSet,CreateSMEventStatement> implements CreateSMEventStatementSet {

    // attributes
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( CreateSMEventStatement createsmeventstatement : this ) createsmeventstatement.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateSMEventStatement createsmeventstatement : this ) createsmeventstatement.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateEventStatementSet R702_is_a_CreateEventStatement() throws XtumlException {
        CreateEventStatementSet createeventstatementset = new CreateEventStatementSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventstatementset.add( createsmeventstatement.R702_is_a_CreateEventStatement() );
        return createeventstatementset;
    }
    @Override
    public CreateEventToClassSet R704_is_a_CreateEventToClass() throws XtumlException {
        CreateEventToClassSet createeventtoclassset = new CreateEventToClassSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventtoclassset.add( createsmeventstatement.R704_is_a_CreateEventToClass() );
        return createeventtoclassset;
    }
    @Override
    public CreateEventToCreatorSet R704_is_a_CreateEventToCreator() throws XtumlException {
        CreateEventToCreatorSet createeventtocreatorset = new CreateEventToCreatorSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventtocreatorset.add( createsmeventstatement.R704_is_a_CreateEventToCreator() );
        return createeventtocreatorset;
    }
    @Override
    public CreateEventToInstanceSet R704_is_a_CreateEventToInstance() throws XtumlException {
        CreateEventToInstanceSet createeventtoinstanceset = new CreateEventToInstanceSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventtoinstanceset.add( createsmeventstatement.R704_is_a_CreateEventToInstance() );
        return createeventtoinstanceset;
    }
    @Override
    public StateMachineEventSet R706_creates_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) statemachineeventset.add( createsmeventstatement.R706_creates_StateMachineEvent() );
        return statemachineeventset;
    }


    @Override
    public CreateSMEventStatement nullElement() {
        return CreateSMEventStatementImpl.EMPTY_CREATESMEVENTSTATEMENT;
    }

    @Override
    public CreateSMEventStatementSet emptySet() {
      return new CreateSMEventStatementSetImpl();
    }

    @Override
    public CreateSMEventStatementSet value() {
        return this;
    }

    @Override
    public List<CreateSMEventStatement> elements() {
        return Arrays.asList(toArray(new CreateSMEventStatement[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateSMEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToClassSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstanceSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToClassSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToCreatorSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreateSMEventStatementSetImpl extends InstanceSet<CreateSMEventStatementSet,CreateSMEventStatement> implements CreateSMEventStatementSet {

    public CreateSMEventStatementSetImpl() {
    }

    public CreateSMEventStatementSetImpl(Comparator<? super CreateSMEventStatement> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( CreateSMEventStatement createsmeventstatement : this ) createsmeventstatement.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateSMEventStatement createsmeventstatement : this ) createsmeventstatement.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateEventStatementSet R702_is_a_CreateEventStatement() throws XtumlException {
        CreateEventStatementSet createeventstatementset = new CreateEventStatementSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventstatementset.add( createsmeventstatement.R702_is_a_CreateEventStatement() );
        return createeventstatementset;
    }
    @Override
    public CreateEventToClassSet R704_is_a_CreateEventToClass() throws XtumlException {
        CreateEventToClassSet createeventtoclassset = new CreateEventToClassSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventtoclassset.add( createsmeventstatement.R704_is_a_CreateEventToClass() );
        return createeventtoclassset;
    }
    @Override
    public CreateEventToCreatorSet R704_is_a_CreateEventToCreator() throws XtumlException {
        CreateEventToCreatorSet createeventtocreatorset = new CreateEventToCreatorSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventtocreatorset.add( createsmeventstatement.R704_is_a_CreateEventToCreator() );
        return createeventtocreatorset;
    }
    @Override
    public CreateEventToInstanceSet R704_is_a_CreateEventToInstance() throws XtumlException {
        CreateEventToInstanceSet createeventtoinstanceset = new CreateEventToInstanceSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) createeventtoinstanceset.add( createsmeventstatement.R704_is_a_CreateEventToInstance() );
        return createeventtoinstanceset;
    }
    @Override
    public StateMachineEventSet R706_creates_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( CreateSMEventStatement createsmeventstatement : this ) statemachineeventset.add( createsmeventstatement.R706_creates_StateMachineEvent() );
        return statemachineeventset;
    }


    @Override
    public CreateSMEventStatement nullElement() {
        return CreateSMEventStatementImpl.EMPTY_CREATESMEVENTSTATEMENT;
    }

    @Override
    public CreateSMEventStatementSet emptySet() {
      return new CreateSMEventStatementSetImpl();
    }

    @Override
    public CreateSMEventStatementSet emptySet(Comparator<? super CreateSMEventStatement> comp) {
      return new CreateSMEventStatementSetImpl(comp);
    }

    @Override
    public CreateSMEventStatementSet value() {
        return this;
    }

    @Override
    public List<CreateSMEventStatement> elements() {
        return Arrays.asList(toArray(new CreateSMEventStatement[0]));
    }

}
